[Scummvm-cvs-logs] SF.net SVN: scummvm:[33882] scummvm/branches/branch-0-12-0/backends/ platform/ds/arm9/source

agent-q at users.sourceforge.net agent-q at users.sourceforge.net
Fri Aug 15 01:07:10 CEST 2008


Revision: 33882
          http://scummvm.svn.sourceforge.net/scummvm/?rev=33882&view=rev
Author:   agent-q
Date:     2008-08-14 23:07:09 +0000 (Thu, 14 Aug 2008)

Log Message:
-----------
DS: fixed for beta2. Cursor icon is hidden when screen tap method is enabled, audio is no longer corrupted when high quality mode is on, Properly enabled AGI and CINE engines, Fix occasional mouse button getting held down

Modified Paths:
--------------
    scummvm/branches/branch-0-12-0/backends/platform/ds/arm9/source/dsmain.cpp
    scummvm/branches/branch-0-12-0/backends/platform/ds/arm9/source/dsmain.h
    scummvm/branches/branch-0-12-0/backends/platform/ds/arm9/source/osystem_ds.cpp

Modified: scummvm/branches/branch-0-12-0/backends/platform/ds/arm9/source/dsmain.cpp
===================================================================
--- scummvm/branches/branch-0-12-0/backends/platform/ds/arm9/source/dsmain.cpp	2008-08-14 22:45:06 UTC (rev 33881)
+++ scummvm/branches/branch-0-12-0/backends/platform/ds/arm9/source/dsmain.cpp	2008-08-14 23:07:09 UTC (rev 33882)
@@ -496,16 +496,12 @@
 		}
 	}
 		
-	if (firstTime) {
+/*	if (firstTime) {
 		firstTime = false;
 
-		if (ConfMan.hasKey("22khzaudio", "ds") && ConfMan.getBool("22khzaudio", "ds")) {
-			startSound(22050, 8192);
-		} else {
-			startSound(11025, 4096);
-		}
 
 	}
+*/
 	#ifdef HEAVY_LOGGING
 	consolePrintf("done\n");
 	#endif
@@ -1288,19 +1284,35 @@
 		//consolePrintf("x=%d   y=%d  \n", getPenX(), getPenY());
 	}
 
+	static bool leftButtonDown = false;
+	static bool rightButtonDown = false;
 
+	if (getPenReleased() && (leftButtonDown || rightButtonDown)) {
+		if (leftButtonDown) {
+			event.type = Common::EVENT_LBUTTONUP;
+		} else {
+			event.type = Common::EVENT_RBUTTONUP;
+		}
+
+		event.mouse = Common::Point(getPenX(), getPenY());
+		system->addEvent(event);
+	}
+
+
 	if ((mouseMode != MOUSE_HOVER) || (!displayModeIs8Bit)) {
 		if (getPenDown() && (!(getKeysHeld() & KEY_L)) && (!(getKeysHeld() & KEY_R))) {	
-			event.type = ((mouseMode == MOUSE_LEFT) || (!displayModeIs8Bit))? Common::EVENT_LBUTTONDOWN: Common::EVENT_RBUTTONDOWN;
+			if ((mouseMode == MOUSE_LEFT) || (!displayModeIs8Bit)) {
+				event.type = Common::EVENT_LBUTTONDOWN;
+				leftButtonDown = true;
+			} else {
+				event.type = Common::EVENT_RBUTTONDOWN;
+				rightButtonDown = true;
+			}
+
 			event.mouse = Common::Point(getPenX(), getPenY());
 			system->addEvent(event);
 		}
 		
-		if (getPenReleased()) {
-			event.type = mouseMode == MOUSE_LEFT? Common::EVENT_LBUTTONUP: Common::EVENT_RBUTTONUP;
-			event.mouse = Common::Point(getPenX(), getPenY());
-			system->addEvent(event);
-		}
 	} else {
 		// In hover mode, D-pad left and right click the mouse when the pen is on the screen
 
@@ -1691,7 +1703,7 @@
 	int offs;
 
 	if (displayModeIs8Bit) {
-		if (!touchPadStyle) {
+		if (!tapScreenClicks) {
 			switch (mouseMode) {
 				case MOUSE_LEFT: {
 					offs = 1;
@@ -2910,7 +2922,7 @@
 	consolePrintf("-------------------------------\n");
 	consolePrintf("ScummVM DS\n");
 	consolePrintf("Ported by Neil Millstone\n");
-	consolePrintf("Version 0.12.0 beta1 ");
+	consolePrintf("Version 0.12.0 beta2 ");
 #if defined(DS_BUILD_A)
 	consolePrintf("build A\n");
 	consolePrintf("Lucasarts SCUMM games (SCUMM)\n");

Modified: scummvm/branches/branch-0-12-0/backends/platform/ds/arm9/source/dsmain.h
===================================================================
--- scummvm/branches/branch-0-12-0/backends/platform/ds/arm9/source/osystem_ds.cpp	2008-08-14 22:45:06 UTC (rev 33881)
+++ scummvm/branches/branch-0-12-0/backends/platform/ds/arm9/source/osystem_ds.cpp	2008-08-14 23:07:09 UTC (rev 33882)
@@ -72,9 +72,15 @@
 	_timer = new DSTimerManager();
     	DS::setTimerCallback(&OSystem_DS::timerHandler, 10);
 
-	_mixer->setOutputRate(11025 /*DS::getSoundFrequency()*/);
+	if (ConfMan.hasKey("22khzaudio", "ds") && ConfMan.getBool("22khzaudio", "ds")) {
+		DS::startSound(22050, 8192);
+	} else {
+		DS::startSound(11025, 4096);
+	}
+
+	_mixer->setOutputRate(DS::getSoundFrequency());
 	_mixer->setReady(true);
-    
+
 	OSystem::initBackend();
 }
 


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list
--- scummvm/branches/branch-0-12-0/backends/platform/ds/arm9/source/dsmain.h	2008-08-14 22:45:06 UTC (rev 33881)
+++ scummvm/branches/branch-0-12-0/backends/platform/ds/arm9/source/dsmain.h	2008-08-14 23:07:09 UTC (rev 33882)
@@ -93,7 +93,8 @@
 void 	doTimerCallback();												// Call callback function if required
 
 // Sound
-void 	doSoundCallback();												// Call function if sound buffers need more data
+void 	doSoundCallback();												void 	startSound(int freq, int buffer);	// Start sound hardware
+// Call function if sound buffers need more data
 void 	playSound(const void* data, u32 length, bool loop, bool adpcm = false, int rate = 22050);		// Start a sound
 void 	stopSound(int channel);
 int		getSoundFrequency();

Modified: scummvm/branches/branch-0-12-0/backends/platform/ds/arm9/source/osystem_ds.cpp
===================================================================